summaryrefslogtreecommitdiff
path: root/src/lib
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2018-07-19 00:42:56 +0100
committerCarl Hetherington <cth@carlh.net>2018-07-19 23:36:56 +0100
commitd3c009991a782fa51e85828c7600994a9dd91559 (patch)
tree8519a3138c11aeb96c8e6c7e8a749c23b7aaf468 /src/lib
parentaf2bea29ef9975dadd26297876e2408e5e874a0c (diff)
More renaming.
sed -i "s/emit_text/emit_plain/g" src/lib/*.cc src/lib/*.h sed -i "s/emit_image_start/emit_bitmap_start/g" src/lib/*.cc src/lib/*.h sed -i "s/emit_text_start/emit_plain_start/g" src/lib/*.cc src/lib/*.h sed -i "s/render_subtitles/render_text/g" src/lib/*.cc src/lib/*.h src/lib/wscript test/*.cc sed -i "s/ImageStart/BitmapStart/g" src/lib/*.cc src/lib/*.h sed -i "s/TextStart/PlainStart/g" src/lib/*.cc src/lib/*.h test/*.cc src/wx/*.cc sed -i "s/ImageSubtitle/BitmapText/g" src/lib/*.cc src/lib/*.h sed -i "s/text_subtitle/plain_text/g" src/lib/*.cc src/lib/*.h src/lib/wscript src/wx/*.cc src/wx/*.h test/*.cc sed -i "s/image_subtitle/bitmap_text/g" src/lib/*.cc src/lib/*.h mv src/lib/render_subtitles.cc src/lib/render_text.cc mv src/lib/render_subtitles.h src/lib/render_text.h mv src/lib/text_subtitle.cc src/lib/plain_text.cc mv src/lib/text_subtitle.h src/lib/plain_text.h
Diffstat (limited to 'src/lib')
-rw-r--r--src/lib/bitmap_text.h48
-rw-r--r--src/lib/content_subtitle.h8
-rw-r--r--src/lib/dcp_decoder.cc2
-rw-r--r--src/lib/dcp_text_decoder.cc4
-rw-r--r--src/lib/ffmpeg_decoder.cc4
-rw-r--r--src/lib/image_subtitle.h4
-rw-r--r--src/lib/plain_text.cc (renamed from src/lib/text_subtitle.cc)2
-rw-r--r--src/lib/plain_text.h (renamed from src/lib/text_subtitle.h)6
-rw-r--r--src/lib/plain_text_content.cc2
-rw-r--r--src/lib/plain_text_decoder.cc2
-rw-r--r--src/lib/plain_text_decoder.h2
-rw-r--r--src/lib/player.cc18
-rw-r--r--src/lib/player.h6
-rw-r--r--src/lib/player_subtitles.h6
-rw-r--r--src/lib/reel_writer.cc2
-rw-r--r--src/lib/render_text.cc (renamed from src/lib/render_subtitles.cc)4
-rw-r--r--src/lib/render_text.h (renamed from src/lib/render_subtitles.h)2
-rw-r--r--src/lib/text_decoder.cc22
-rw-r--r--src/lib/text_decoder.h14
-rw-r--r--src/lib/text_file_decoder.cc2
-rw-r--r--src/lib/wscript4
21 files changed, 106 insertions, 58 deletions
diff --git a/src/lib/bitmap_text.h b/src/lib/bitmap_text.h
new file mode 100644
index 000000000..64de7686d
--- /dev/null
+++ b/src/lib/bitmap_text.h
@@ -0,0 +1,48 @@
+/*
+ Copyright (C) 2014-2018 Carl Hetherington <cth@carlh.net>
+
+ This file is part of DCP-o-matic.
+
+ DCP-o-matic is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by
+ the Free Software Foundation; either version 2 of the License, or
+ (at your option) any later version.
+
+ DCP-o-matic is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ GNU General Public License for more details.
+
+ You should have received a copy of the GNU General Public License
+ along with DCP-o-matic. If not, see <http://www.gnu.org/licenses/>.
+
+*/
+
+#ifndef DCPOMATIC_BITMAP_TEXT_H
+#define DCPOMATIC_BITMAP_TEXT_H
+
+#include "rect.h"
+#include <boost/shared_ptr.hpp>
+
+class Image;
+
+class BitmapText
+{
+public:
+ BitmapText (boost::shared_ptr<Image> i, dcpomatic::Rect<double> r)
+ : image (i)
+ , rectangle (r)
+ {}
+
+ boost::shared_ptr<Image> image;
+ /** Area that the subtitle covers on its corresponding video, expressed in
+ * proportions of the image size; e.g. rectangle.x = 0.5 would mean that
+ * the rectangle starts half-way across the video.
+ *
+ * This rectangle may or may not have had a TextContent's offsets and
+ * scale applied to it, depending on context.
+ */
+ dcpomatic::Rect<double> rectangle;
+};
+
+#endif
diff --git a/src/lib/content_subtitle.h b/src/lib/content_subtitle.h
index f834fe197..5a3e8157c 100644
--- a/src/lib/content_subtitle.h
+++ b/src/lib/content_subtitle.h
@@ -23,7 +23,7 @@
#include "dcpomatic_time.h"
#include "rect.h"
-#include "image_subtitle.h"
+#include "bitmap_text.h"
#include <dcp/subtitle_string.h>
#include <list>
@@ -44,16 +44,16 @@ private:
ContentTime _from;
};
-class ContentImageSubtitle : public ContentSubtitle
+class ContentBitmapText : public ContentSubtitle
{
public:
- ContentImageSubtitle (ContentTime f, boost::shared_ptr<Image> im, dcpomatic::Rect<double> r)
+ ContentBitmapText (ContentTime f, boost::shared_ptr<Image> im, dcpomatic::Rect<double> r)
: ContentSubtitle (f)
, sub (im, r)
{}
/* Our subtitle, with its rectangle unmodified by any offsets or scales that the content specifies */
- ImageSubtitle sub;
+ BitmapText sub;
};
/** A text subtitle. We store the time period separately (as well as in the dcp::SubtitleStrings)
diff --git a/src/lib/dcp_decoder.cc b/src/lib/dcp_decoder.cc
index 03bd95d90..6a9de841d 100644
--- a/src/lib/dcp_decoder.cc
+++ b/src/lib/dcp_decoder.cc
@@ -209,7 +209,7 @@ DCPDecoder::pass_subtitles (ContentTime next)
if (is) {
list<dcp::SubtitleString> s;
s.push_back (*is);
- subtitle->emit_text (
+ subtitle->emit_plain (
ContentTimePeriod (
ContentTime::from_frames (_offset - entry_point, vfr) + ContentTime::from_seconds (i->in().as_seconds ()),
ContentTime::from_frames (_offset - entry_point, vfr) + ContentTime::from_seconds (i->out().as_seconds ())
diff --git a/src/lib/dcp_text_decoder.cc b/src/lib/dcp_text_decoder.cc
index 576cfd357..168bfa5cc 100644
--- a/src/lib/dcp_text_decoder.cc
+++ b/src/lib/dcp_text_decoder.cc
@@ -63,7 +63,7 @@ DCPTextDecoder::pass ()
/* Gather all subtitles with the same time period that are next
on the list. We must emit all subtitles for the same time
- period with the same text_subtitle() call otherwise the
+ period with the same plain_text() call otherwise the
TextDecoder will assume there is nothing else at the
time of emit the first.
*/
@@ -81,7 +81,7 @@ DCPTextDecoder::pass ()
/* XXX: image subtitles */
}
- subtitle->emit_text (p, s);
+ subtitle->emit_plain (p, s);
return false;
}
diff --git a/src/lib/ffmpeg_decoder.cc b/src/lib/ffmpeg_decoder.cc
index 4d10f8ef7..909a9d443 100644
--- a/src/lib/ffmpeg_decoder.cc
+++ b/src/lib/ffmpeg_decoder.cc
@@ -669,7 +669,7 @@ FFmpegDecoder::decode_bitmap_subtitle (AVSubtitleRect const * rect, ContentTime
static_cast<double> (rect->h) / target_height
);
- subtitle->emit_image_start (from, image, scaled_rect);
+ subtitle->emit_bitmap_start (from, image, scaled_rect);
}
void
@@ -702,6 +702,6 @@ FFmpegDecoder::decode_ass_subtitle (string ass, ContentTime from)
);
BOOST_FOREACH (sub::Subtitle const & i, sub::collect<list<sub::Subtitle> > (raw)) {
- subtitle->emit_text_start (from, i);
+ subtitle->emit_plain_start (from, i);
}
}
diff --git a/src/lib/image_subtitle.h b/src/lib/image_subtitle.h
index e0687e581..1d2dcd793 100644
--- a/src/lib/image_subtitle.h
+++ b/src/lib/image_subtitle.h
@@ -26,10 +26,10 @@
class Image;
-class ImageSubtitle
+class BitmapText
{
public:
- ImageSubtitle (boost::shared_ptr<Image> i, dcpomatic::Rect<double> r)
+ BitmapText (boost::shared_ptr<Image> i, dcpomatic::Rect<double> r)
: image (i)
, rectangle (r)
{}
diff --git a/src/lib/text_subtitle.cc b/src/lib/plain_text.cc
index 35801e160..ee9bc4b8b 100644
--- a/src/lib/text_subtitle.cc
+++ b/src/lib/plain_text.cc
@@ -18,7 +18,7 @@
*/
-#include "text_subtitle.h"
+#include "plain_text.h"
#include "cross.h"
#include "exceptions.h"
#include "plain_text_content.h"
diff --git a/src/lib/text_subtitle.h b/src/lib/plain_text.h
index 60571a439..61d714702 100644
--- a/src/lib/text_subtitle.h
+++ b/src/lib/plain_text.h
@@ -27,10 +27,10 @@
#include <vector>
class PlainText;
-class text_subtitle_time_test;
-class text_subtitle_coordinate_test;
+class plain_text_time_test;
+class plain_text_coordinate_test;
class plain_text_content_test;
-class text_subtitle_parse_test;
+class plain_text_parse_test;
class TextSubtitle
{
diff --git a/src/lib/plain_text_content.cc b/src/lib/plain_text_content.cc
index 6ca783c16..f51e365d5 100644
--- a/src/lib/plain_text_content.cc
+++ b/src/lib/plain_text_content.cc
@@ -20,7 +20,7 @@
#include "plain_text_content.h"
#include "util.h"
-#include "text_subtitle.h"
+#include "plain_text.h"
#include "film.h"
#include "font.h"
#include "text_content.h"
diff --git a/src/lib/plain_text_decoder.cc b/src/lib/plain_text_decoder.cc
index 71f7bed42..46a4bd552 100644
--- a/src/lib/plain_text_decoder.cc
+++ b/src/lib/plain_text_decoder.cc
@@ -72,7 +72,7 @@ TextTextDecoder::pass ()
}
ContentTimePeriod const p = content_time_period (_subtitles[_next]);
- subtitle->emit_text (p, _subtitles[_next]);
+ subtitle->emit_plain (p, _subtitles[_next]);
++_next;
return false;
diff --git a/src/lib/plain_text_decoder.h b/src/lib/plain_text_decoder.h
index 4bdedf58d..046c5f8e0 100644
--- a/src/lib/plain_text_decoder.h
+++ b/src/lib/plain_text_decoder.h
@@ -22,7 +22,7 @@
#define DCPOMATIC_TEXT_SUBTITLE_DECODER_H
#include "text_decoder.h"
-#include "text_subtitle.h"
+#include "plain_text.h"
class PlainText;
diff --git a/src/lib/player.cc b/src/lib/player.cc
index b701deb5e..92e8141e1 100644
--- a/src/lib/player.cc
+++ b/src/lib/player.cc
@@ -28,7 +28,7 @@
#include "raw_image_proxy.h"
#include "ratio.h"
#include "log.h"
-#include "render_subtitles.h"
+#include "render_text.h"
#include "config.h"
#include "content_video.h"
#include "player_video.h"
@@ -167,8 +167,8 @@ Player::setup_pieces ()
}
if (decoder->subtitle) {
- decoder->subtitle->ImageStart.connect (bind (&Player::image_subtitle_start, this, weak_ptr<Piece> (piece), _1));
- decoder->subtitle->TextStart.connect (bind (&Player::text_subtitle_start, this, weak_ptr<Piece> (piece), _1));
+ decoder->subtitle->BitmapStart.connect (bind (&Player::bitmap_text_start, this, weak_ptr<Piece> (piece), _1));
+ decoder->subtitle->PlainStart.connect (bind (&Player::plain_text_start, this, weak_ptr<Piece> (piece), _1));
decoder->subtitle->Stop.connect (bind (&Player::subtitle_stop, this, weak_ptr<Piece> (piece), _1));
}
}
@@ -290,11 +290,11 @@ Player::film_changed (Film::Property p)
}
list<PositionImage>
-Player::transform_image_subtitles (list<ImageSubtitle> subs) const
+Player::transform_bitmap_texts (list<BitmapText> subs) const
{
list<PositionImage> all;
- for (list<ImageSubtitle>::const_iterator i = subs.begin(); i != subs.end(); ++i) {
+ for (list<BitmapText>::const_iterator i = subs.begin(); i != subs.end(); ++i) {
if (!i->image) {
continue;
}
@@ -667,12 +667,12 @@ Player::subtitles_for_frame (DCPTime time) const
BOOST_FOREACH (PlayerSubtitles i, _active_subtitles.get_burnt (DCPTimePeriod(time, time + DCPTime::from_frames(1, vfr)), _always_burn_subtitles)) {
/* Image subtitles */
- list<PositionImage> c = transform_image_subtitles (i.image);
+ list<PositionImage> c = transform_bitmap_texts (i.image);
copy (c.begin(), c.end(), back_inserter (subtitles));
/* Text subtitles (rendered to an image) */
if (!i.text.empty ()) {
- list<PositionImage> s = render_subtitles (i.text, i.fonts, _video_container_size, time, vfr);
+ list<PositionImage> s = render_text (i.text, i.fonts, _video_container_size, time, vfr);
copy (s.begin(), s.end(), back_inserter (subtitles));
}
}
@@ -840,7 +840,7 @@ Player::audio (weak_ptr<Piece> wp, AudioStreamPtr stream, ContentAudio content_a
}
void
-Player::image_subtitle_start (weak_ptr<Piece> wp, ContentImageSubtitle subtitle)
+Player::bitmap_text_start (weak_ptr<Piece> wp, ContentBitmapText subtitle)
{
shared_ptr<Piece> piece = wp.lock ();
if (!piece) {
@@ -867,7 +867,7 @@ Player::image_subtitle_start (weak_ptr<Piece> wp, ContentImageSubtitle subtitle)
}
void
-Player::text_subtitle_start (weak_ptr<Piece> wp, ContentTextSubtitle subtitle)
+Player::plain_text_start (weak_ptr<Piece> wp, ContentTextSubtitle subtitle)
{
shared_ptr<Piece> piece = wp.lock ();
if (!piece) {
diff --git a/src/lib/player.h b/src/lib/player.h
index 54fa074c0..b0ffe0e04 100644
--- a/src/lib/player.h
+++ b/src/lib/player.h
@@ -116,7 +116,7 @@ private:
void film_changed (Film::Property);
void playlist_changed ();
void playlist_content_changed (boost::weak_ptr<Content>, int, bool);
- std::list<PositionImage> transform_image_subtitles (std::list<ImageSubtitle>) const;
+ std::list<PositionImage> transform_bitmap_texts (std::list<BitmapText>) const;
Frame dcp_to_content_video (boost::shared_ptr<const Piece> piece, DCPTime t) const;
DCPTime content_video_to_dcp (boost::shared_ptr<const Piece> piece, Frame f) const;
Frame dcp_to_resampled_audio (boost::shared_ptr<const Piece> piece, DCPTime t) const;
@@ -126,8 +126,8 @@ private:
boost::shared_ptr<PlayerVideo> black_player_video_frame (Eyes eyes) const;
void video (boost::weak_ptr<Piece>, ContentVideo);
void audio (boost::weak_ptr<Piece>, AudioStreamPtr, ContentAudio);
- void image_subtitle_start (boost::weak_ptr<Piece>, ContentImageSubtitle);
- void text_subtitle_start (boost::weak_ptr<Piece>, ContentTextSubtitle);
+ void bitmap_text_start (boost::weak_ptr<Piece>, ContentBitmapText);
+ void plain_text_start (boost::weak_ptr<Piece>, ContentTextSubtitle);
void subtitle_stop (boost::weak_ptr<Piece>, ContentTime);
DCPTime one_video_frame () const;
void fill_audio (DCPTimePeriod period);
diff --git a/src/lib/reel_writer.cc b/src/lib/reel_writer.cc
index 24ab1c534..197773a20 100644
--- a/src/lib/reel_writer.cc
+++ b/src/lib/reel_writer.cc
@@ -563,7 +563,7 @@ ReelWriter::write (PlayerSubtitles subs, DCPTimePeriod period)
_subtitle_asset->add (shared_ptr<dcp::Subtitle>(new dcp::SubtitleString(i)));
}
- BOOST_FOREACH (ImageSubtitle i, subs.image) {
+ BOOST_FOREACH (BitmapText i, subs.image) {
_subtitle_asset->add (
shared_ptr<dcp::Subtitle>(
new dcp::SubtitleImage(
diff --git a/src/lib/render_subtitles.cc b/src/lib/render_text.cc
index 35fcd8b93..673078347 100644
--- a/src/lib/render_subtitles.cc
+++ b/src/lib/render_text.cc
@@ -18,7 +18,7 @@
*/
-#include "render_subtitles.h"
+#include "render_text.h"
#include "types.h"
#include "image.h"
#include "cross.h"
@@ -365,7 +365,7 @@ render_line (list<SubtitleString> subtitles, list<shared_ptr<Font> > fonts, dcp:
* @param frame_rate DCP frame rate.
*/
list<PositionImage>
-render_subtitles (list<SubtitleString> subtitles, list<shared_ptr<Font> > fonts, dcp::Size target, DCPTime time, int frame_rate)
+render_text (list<SubtitleString> subtitles, list<shared_ptr<Font> > fonts, dcp::Size target, DCPTime time, int frame_rate)
{
list<SubtitleString> pending;
list<PositionImage> images;
diff --git a/src/lib/render_subtitles.h b/src/lib/render_text.h
index b1239bb3d..0f3a31e21 100644
--- a/src/lib/render_subtitles.h
+++ b/src/lib/render_text.h
@@ -26,6 +26,6 @@
class Font;
std::string marked_up (std::list<SubtitleString> subtitles, int target_height, float fade_factor);
-std::list<PositionImage> render_subtitles (
+std::list<PositionImage> render_text (
std::list<SubtitleString>, std::list<boost::shared_ptr<Font> > fonts, dcp::Size, DCPTime, int
);
diff --git a/src/lib/text_decoder.cc b/src/lib/text_decoder.cc
index 56a7e1e15..8b825936a 100644
--- a/src/lib/text_decoder.cc
+++ b/src/lib/text_decoder.cc
@@ -58,14 +58,14 @@ TextDecoder::TextDecoder (
* of the video frame)
*/
void
-TextDecoder::emit_image_start (ContentTime from, shared_ptr<Image> image, dcpomatic::Rect<double> rect)
+TextDecoder::emit_bitmap_start (ContentTime from, shared_ptr<Image> image, dcpomatic::Rect<double> rect)
{
- ImageStart (ContentImageSubtitle (from, image, rect));
+ BitmapStart (ContentBitmapText (from, image, rect));
_position = from;
}
void
-TextDecoder::emit_text_start (ContentTime from, list<dcp::SubtitleString> s)
+TextDecoder::emit_plain_start (ContentTime from, list<dcp::SubtitleString> s)
{
BOOST_FOREACH (dcp::SubtitleString& i, s) {
/* We must escape < and > in strings, otherwise they might confuse our subtitle
@@ -94,12 +94,12 @@ TextDecoder::emit_text_start (ContentTime from, list<dcp::SubtitleString> s)
}
}
- TextStart (ContentTextSubtitle (from, s));
+ PlainStart (ContentTextSubtitle (from, s));
_position = from;
}
void
-TextDecoder::emit_text_start (ContentTime from, sub::Subtitle const & subtitle)
+TextDecoder::emit_plain_start (ContentTime from, sub::Subtitle const & subtitle)
{
/* See if our next subtitle needs to be vertically placed on screen by us */
bool needs_placement = false;
@@ -191,7 +191,7 @@ TextDecoder::emit_text_start (ContentTime from, sub::Subtitle const & subtitle)
/* The idea here (rightly or wrongly) is that we set the appearance based on the
values in the libsub objects, and these are overridden with values from the
- content by the other emit_text_start() above.
+ content by the other emit_plain_start() above.
*/
out.push_back (
@@ -227,7 +227,7 @@ TextDecoder::emit_text_start (ContentTime from, sub::Subtitle const & subtitle)
}
}
- emit_text_start (from, out);
+ emit_plain_start (from, out);
}
void
@@ -237,16 +237,16 @@ TextDecoder::emit_stop (ContentTime to)
}
void
-TextDecoder::emit_text (ContentTimePeriod period, list<dcp::SubtitleString> s)
+TextDecoder::emit_plain (ContentTimePeriod period, list<dcp::SubtitleString> s)
{
- emit_text_start (period.from, s);
+ emit_plain_start (period.from, s);
emit_stop (period.to);
}
void
-TextDecoder::emit_text (ContentTimePeriod period, sub::Subtitle const & s)
+TextDecoder::emit_plain (ContentTimePeriod period, sub::Subtitle const & s)
{
- emit_text_start (period.from, s);
+ emit_plain_start (period.from, s);
emit_stop (period.to);
}
diff --git a/src/lib/text_decoder.h b/src/lib/text_decoder.h
index d9d351d92..221ed6d37 100644
--- a/src/lib/text_decoder.h
+++ b/src/lib/text_decoder.h
@@ -49,11 +49,11 @@ public:
return _position;
}
- void emit_image_start (ContentTime from, boost::shared_ptr<Image> image, dcpomatic::Rect<double> rect);
- void emit_text_start (ContentTime from, std::list<dcp::SubtitleString> s);
- void emit_text_start (ContentTime from, sub::Subtitle const & subtitle);
- void emit_text (ContentTimePeriod period, std::list<dcp::SubtitleString> s);
- void emit_text (ContentTimePeriod period, sub::Subtitle const & subtitle);
+ void emit_bitmap_start (ContentTime from, boost::shared_ptr<Image> image, dcpomatic::Rect<double> rect);
+ void emit_plain_start (ContentTime from, std::list<dcp::SubtitleString> s);
+ void emit_plain_start (ContentTime from, sub::Subtitle const & subtitle);
+ void emit_plain (ContentTimePeriod period, std::list<dcp::SubtitleString> s);
+ void emit_plain (ContentTimePeriod period, sub::Subtitle const & subtitle);
void emit_stop (ContentTime to);
void seek ();
@@ -62,8 +62,8 @@ public:
return _content;
}
- boost::signals2::signal<void (ContentImageSubtitle)> ImageStart;
- boost::signals2::signal<void (ContentTextSubtitle)> TextStart;
+ boost::signals2::signal<void (ContentBitmapText)> BitmapStart;
+ boost::signals2::signal<void (ContentTextSubtitle)> PlainStart;
boost::signals2::signal<void (ContentTime)> Stop;
private:
diff --git a/src/lib/text_file_decoder.cc b/src/lib/text_file_decoder.cc
index 1dba3acd0..a6d7b327b 100644
--- a/src/lib/text_file_decoder.cc
+++ b/src/lib/text_file_decoder.cc
@@ -68,7 +68,7 @@ TextTextDecoder::pass ()
}
ContentTimePeriod const p = content_time_period (_subtitles[_next]);
- subtitle->emit_text (p, _subtitles[_next]);
+ subtitle->emit_plain (p, _subtitles[_next]);
++_next;
return false;
diff --git a/src/lib/wscript b/src/lib/wscript
index b3e04e28b..dd7c87f39 100644
--- a/src/lib/wscript
+++ b/src/lib/wscript
@@ -119,7 +119,7 @@ sources = """
ratio.cc
raw_image_proxy.cc
reel_writer.cc
- render_subtitles.cc
+ render_text.cc
resampler.cc
rgba.cc
scoped_temporary.cc
@@ -134,7 +134,7 @@ sources = """
string_log_entry.cc
text_content.cc
text_decoder.cc
- text_subtitle.cc
+ plain_text.cc
plain_text_content.cc
plain_text_decoder.cc
timer.cc
diff --git a/src/lib/player_subtitles.h b/src/lib/player_subtitles.h
index e1a104f21..4e3a739d8 100644
--- a/src/lib/player_subtitles.h
+++ b/src/lib/player_subtitles.h
@@ -21,7 +21,7 @@
#ifndef DCPOMATIC_PLAYER_SUBTITLES_H
#define DCPOMATIC_PLAYER_SUBTITLES_H
-#include "image_subtitle.h"
+#include "bitmap_text.h"
#include "dcpomatic_time.h"
#include "subtitle_string.h"
@@ -34,8 +34,8 @@ public:
void add_fonts (std::list<boost::shared_ptr<Font> > fonts_);
std::list<boost::shared_ptr<Font> > fonts;
- /** ImageSubtitles, with their rectangles transformed as specified by their content */
- std::list<ImageSubtitle> image;
+ /** BitmapTexts, with their rectangles transformed as specified by their content */
+ std::list<BitmapText> image;
std::list<SubtitleString> text;
};